import rss from '@astrojs/rss';
import { getCollection } from 'astro:content';

/**
 * @type {import('astro').APIRoute}
 */
export async function GET(context) {
  const [blogPosts, libraryItems] = await Promise.all([
    getCollection('blog'),
    getCollection('library'),
  ]);
  return rss({
    title: 'Filipe Medeiros - personal website',
    description:
      "Filipe Medeiros' personal website. It has a blog and a library with things he's read or seen.",
    site: context.site,
    items: libraryItems
      .map((item) => ({
        title: item.data.title,
        pubDate: item.data.date,
        description: item.data.description,
        author: 'hello@filipesm.eu',
        categories: item.id.startsWith('en')
          ? ['library', 'English']
          : ['biblioteca', 'português'],
      }))
      .concat(
        blogPosts.map((post) => ({
          title: post.data.title,
          pubDate: post.data.publishDate,
          description: post.data.summary,
          link: `${post.id.startsWith('en/') ? '/blog' : '/blogue'}/${
            post.slug
          }`,
          author: 'hello@filipesm.eu',
          categories: post.id.startsWith('en')
            ? ['blog', 'English']
            : ['blogue', 'português'],
        })),
      ),
  });
}
